 
| file name                                                                                                                       | uuid1                                                                                                                           | data sources                                                                                                                    | macroatom                                                                                                                       | zeta                                                                                                                            | synpp references                                                                                                                | database version                                                                                                                |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
 
| `kurucz_cd23_chianti_H_He.zip <http://moria.astro.utoronto.ca/~wkerzend/tardis_atomic_databases/kurucz_cd23_chianti_H_He.zip>`_ | 5ca3035ca8b311e3bb684437e69d75d7                                                                                                | **kurucz:**                                                                                                                     | True                                                                                                                            | True                                                                                                                            | True                                                                                                                            | v0.9                                                                                                                            |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Li I-II, Be I-IV, C I-IV, N I-VI                                                                                                |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | O I-VI, F I-VI, Ne I-VI, Na I-VI                                                                                                |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Mg I-VI, Al I-VI, Si I-VI                                                                                                       |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | P I-VI, S I-VI, Cl I-V, Ar I-V                                                                                                  |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | K I-V, Ca I-IX, Sc I-IX, Ti I-IX                                                                                                |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | V I-IX, Cr I-IX, Mn I-IX, Fe I-IX                                                                                               |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Co I-IX, Ni I-IX, Cu I-II                                                                                                       |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Zn I-III                                                                                                                        |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | **chianti:**                                                                                                                    |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | H I,He I-II                                                                                                                     |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | **tardis_artificial_missing_ion:**                                                                                              |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Li III, B V, C V-VI, N VII, O VII-VIII                                                                                          |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | F VII-IX, Ne VII-X, Na VII-XI                                                                                                   |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Mg VII-XII, Al VII-XIII                                                                                                         |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Si VII-XIV, P VII-XV, S VII-XVI                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Cl VI-XVII, Ar VI-XVIII                                                                                                         |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | K VI-XIX, Ca X-XX, Sc X-XXI                                                                                                     |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Ti X-XXII, V X-XXIII, Cr X-XXIV                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Mn X-XXV, Fe X-XXVI, Co X-XXVII                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Ni X-XXVIII, Cu III-XXIX                                                                                                        |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 | Zn IV-XXX                                                                                                                       |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
|                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |                                                                                                                                 |
 
